==> nova-2014.2.b2.tar.gz: nova-2014.2.b2/nova/api/openstack/compute/schemas/v3/attach_interfaces.py <==
# Copyright 2014 NEC Corporation.  All rights reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

create = {
    'type': 'object',
    'properties': {
        'interface_attachment': {
            'type': 'object',
            'properties': {
                'net_id': {
                    # NOTE: This parameter is passed to the search_opts of
                    # Neutron list_network API: search_opts = {'id': net_id}
                    # A network id should be uuid.
                    'type': 'string', 'format': 'uuid',
                },
                'port_id': {
                    # NOTE: This parameter is passed to Neutron show_port API
                    # as a port id. A port id should be uuid.
                    'type': 'string', 'format': 'uuid',
                },
                'fixed_ips': {
                    'type': 'array', 'minItems': 1, 'maxItems': 1,
                    'items': {
                        'type': 'object',
                        'properties': {
                            'ip_address': {
                                'type': 'string',
                                'oneOf': [
                                    {'format': 'ipv4'},
                                    {'format': 'ipv6'}
                                ],
                            },
                        },
                        'required': ['ip_address'],
                        'additionalProperties': False,
                    },
                },
            },
            'additionalProperties': False,
        },
    },
    'additionalProperties': False,
}

==> nova-2015.1.0b1.tar.gz: nova-2015.1.0b1/nova/api/openstack/compute/schemas/v3/attach_interfaces.py <==
# Copyright 2014 NEC Corporation.  All rights reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from nova.api.validation import parameter_types


create = {
    'type': 'object',
    'properties': {
        'interfaceAttachment': {
            'type': 'object',
            'properties': {
                # NOTE: This parameter is passed to the search_opts of
                # Neutron list_network API: search_opts = {'id': net_id}
                'net_id': parameter_types.network_id,
                # NOTE: This parameter is passed to Neutron show_port API
                # as a port id.
                'port_id': parameter_types.network_port_id,
                'fixed_ips': {
                    'type': 'array', 'minItems': 1, 'maxItems': 1,
                    'items': {
                        'type': 'object',
                        'properties': {
                            'ip_address': {
                                'type': 'string',
                                'oneOf': [
                                    {'format': 'ipv4'},
                                    {'format': 'ipv6'}
                                ],
                            },
                        },
                        'required': ['ip_address'],
                        'additionalProperties': False,
                    },
                },
            },
            'additionalProperties': False,
        },
    },
    'additionalProperties': False,
}
